@@ -15,6 +15,7 @@
  */
 
 #include "dailymotionvideowindow.h"
+#include "clipboard.h"
 #include "dailymotion.h"
 #include "dailymotioncommentdelegate.h"
 #include "dailymotioncommentdialog.h"
@@ -46,6 +47,7 @@
 #include <QMessageBox>
 #include <QMenuBar>
 #include <QDesktopServices>
+#include <QMaemo5InformationBox>
 
 DailymotionVideoWindow::DailymotionVideoWindow(const QString &id, StackedWindow *parent) :
     StackedWindow(parent),
@@ -75,11 +77,13 @@ DailymotionVideoWindow::DailymotionVideoWindow(const QString &id, StackedWindow
     m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_downloadAction(new QAction(tr("Download"), this)),
+    m_shareAction(new QAction(tr("Copy URL"), this)),
     m_favouriteAction(0),
     m_playlistAction(0),
     m_commentAction(0),
     m_contextMenu(new QMenu(this)),
     m_relatedDownloadAction(new QAction(tr("Download"), this)),
+    m_relatedShareAction(new QAction(tr("Copy URL"), this)),
     m_relatedFavouriteAction(0),
     m_relatedPlaylistAction(0)
 {
@@ -118,11 +122,13 @@ DailymotionVideoWindow::DailymotionVideoWindow(const DailymotionVideo *video, St
     m_gridAction(new QAction(tr("Grid"), this)),
     m_reloadAction(new QAction(tr("Reload"), this)),
     m_downloadAction(new QAction(tr("Download"), this)),
+    m_shareAction(new QAction(tr("Copy URL"), this)),
     m_favouriteAction(0),
     m_playlistAction(0),
     m_commentAction(0),
     m_contextMenu(new QMenu(this)),
     m_relatedDownloadAction(new QAction(tr("Download"), this)),
+    m_relatedShareAction(new QAction(tr("Copy URL"), this)),
     m_relatedFavouriteAction(0),
     m_relatedPlaylistAction(0)
 {
@@ -164,6 +170,7 @@ void DailymotionVideoWindow::loadBaseUi() {
     m_reloadAction->setEnabled(false);
     
     m_contextMenu->addAction(m_relatedDownloadAction);
+    m_contextMenu->addAction(m_relatedShareAction);
     
     QWidget *scrollWidget = new QWidget(m_scrollArea);
     QGridLayout *grid = new QGridLayout(scrollWidget);
@@ -201,6 +208,7 @@ void DailymotionVideoWindow::loadBaseUi() {
     menuBar()->addAction(m_gridAction);
     menuBar()->addAction(m_reloadAction);
     menuBar()->addAction(m_downloadAction);
+    menuBar()->addAction(m_shareAction);
     
     connect(m_relatedModel, SIGNAL(statusChanged(QDailymotion::ResourcesRequest::Status)), this,
             SLOT(onRelatedModelStatusChanged(QDailymotion::ResourcesRequest::Status)));
@@ -216,7 +224,9 @@ void DailymotionVideoWindow::loadBaseUi() {
     connect(m_avatar, SIGNAL(clicked()), this, SLOT(showUser()));
     connect(m_descriptionLabel, SIGNAL(anchorClicked(QUrl)), this, SLOT(showResource(QUrl)));
     connect(m_downloadAction, SIGNAL(triggered()), this, SLOT(downloadVideo()));
+    connect(m_shareAction, SIGNAL(triggered()), this, SLOT(shareVideo()));
     connect(m_relatedDownloadAction, SIGNAL(triggered()), this, SLOT(downloadRelatedVideo()));
+    connect(m_relatedShareAction, SIGNAL(triggered()), this, SLOT(shareRelatedVideo()));
     
     if (!Dailymotion::instance()->userId().isEmpty()) {        
         if (Dailymotion::instance()->hasScope(QDailymotion::MANAGE_FAVORITES_SCOPE)) {
@@ -347,6 +357,11 @@ void DailymotionVideoWindow::setVideoFavourite() {
     }
 }
 
+void DailymotionVideoWindow::shareVideo() {
+    Clipboard::instance()->setText("http://wwww.dailymotion.com/video/" + m_video->id());
+    QMaemo5InformationBox::information(this, tr("URL copied to clipboard"));
+}
+
 void DailymotionVideoWindow::addRelatedVideoToPlaylist() {
     if (isBusy()) {
         return;
@@ -407,6 +422,13 @@ void DailymotionVideoWindow::setRelatedVideoFavourite() {
     }
 }
 
+void DailymotionVideoWindow::shareRelatedVideo() {
+    if (const DailymotionVideo *video = m_relatedModel->get(m_relatedView->currentIndex().row())) {
+        Clipboard::instance()->setText("http://wwww.dailymotion.com/video/" + video->id());
+        QMaemo5InformationBox::information(this, tr("URL copied to clipboard"));
+    }
+}
+
 void DailymotionVideoWindow::showRelatedVideo(const QModelIndex &index) {
     if (isBusy()) {
         return;
