@@ -33,6 +33,7 @@
 #include "textbrowser.h"
 #include "utils.h"
 #include "videoplaybackwindow.h"
+#include "videoplayer.h"
 #include "videothumbnail.h"
 #include <QScrollArea>
 #include <QTabBar>
@@ -276,6 +277,9 @@ void PluginVideoWindow::playVideo() {
         window->show();
         window->addVideo(m_video);
     }
+    else if (!m_video->streamUrl().isEmpty()) {
+        VideoPlayer::playVideo(m_video->streamUrl().toString());
+    }
     else {
         PluginPlaybackDialog *dialog = new PluginPlaybackDialog(m_video->service(), m_video->id(), m_video->title(), this);
         dialog->open();
@@ -310,11 +314,18 @@ void PluginVideoWindow::playRelatedVideo(const QModelIndex &index) {
         }
     }
     else {
-        QString id = index.data(PluginVideoModel::IdRole).toString();
-        QString title = index.data(PluginVideoModel::TitleRole).toString();
+        QString url = index.data(PluginVideoModel::StreamUrlRole).toString();
+        
+        if (!url.isEmpty()) {
+            VideoPlayer::playVideo(url);
+        }
+        else {
+            QString id = index.data(PluginVideoModel::IdRole).toString();
+            QString title = index.data(PluginVideoModel::TitleRole).toString();
     
-        PluginPlaybackDialog *dialog = new PluginPlaybackDialog(m_video->service(), id, title, this);
-        dialog->open();
+            PluginPlaybackDialog *dialog = new PluginPlaybackDialog(m_video->service(), id, title, this);
+            dialog->open();
+        }
     }
 }
 
